CvStruct<T extends Struct> class
abstract
- Inheritance
- Implementers
- AlignMTB
- ArucoDetector
- ArucoDetectorParameters
- ArucoDictionary
- ArucoRefineParameters
- AsyncArray
- BackgroundSubtractorKNN
- BackgroundSubtractorMOG2
- BFMatcher
- BlockMeanHash
- CascadeClassifier
- CharucoBoard
- CharucoDetector
- CharucoDetectorParameters
- CLAHE
- CvVec
- DMatch
- EdgeBoxes
- EdgeDrawing
- EdgeDrawingParams
- FaceDetectorYN
- FaceRecognizerSF
- Feature2D
- FlannBasedMatcher
- FlannIndexParams
- FreeType2
- GComputation
- GMat
- GraphSegmentation
- GScalar
- HOGDescriptor
- KalmanFilter
- KeyPoint
- Layer
- LineSegmentDetector
- Mat
- MergeMertens
- Moments
- Net
- Point
- Point2d
- Point2f
- Point3f
- Point3i
- QRCodeDetector
- QualityBRISQUE
- QualityGMSD
- QualityMSE
- QualityPSNR
- QualitySSIM
- Rect
- Rect2f
- RFFeatureGetter
- Rng
- RotatedRect
- Scalar
- SimpleBlobDetectorParams
- Size
- Size2f
- StereoBM
- StereoSGBM
- Stitcher
- StructuredEdgeDetection
- Subdiv2D
- TermCriteria
- TrackerMIL
- UMat
- UsacParams
- VideoCapture
- VideoWriter
- WBDetector
- WeChatQRCode
Constructors
-
CvStruct.fromPointer(Pointer<
T> ptr)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDisposed → bool
-
Whether this object has been disposed.
no setterinherited
-
props
→ List<
Object?> -
no setterinherited
-
ptr
↔ Pointer<
T> -
getter/setter pairinherited
- ref → T
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → void -
Releases the underlying native resources. Idempotent: calling it more
than once is safe, but the object must not be used after dispose.
inherited
-
freeNative(
) → void -
Frees the native resources owned by this object. Subclasses implement the
concrete free logic here; callers must use dispose instead.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited