SimpleBlobDetectorParams class

Inheritance

Constructors

SimpleBlobDetectorParams({int? blobColor, bool? filterByArea, bool? filterByCircularity, bool? filterByColor, bool? filterByConvexity, bool? filterByInertia, double? maxArea, double? maxCircularity, double? maxConvexity, double? maxInertiaRatio, double? maxThreshold, double? minArea, double? minCircularity, double? minConvexity, double? minDistBetweenBlobs, double? minInertiaRatio, int? minRepeatability, double? minThreshold, double? thresholdStep})
factory
SimpleBlobDetectorParams.empty()
factory
SimpleBlobDetectorParams.fromNative(SimpleBlobDetectorParams r)
factory
SimpleBlobDetectorParams.fromPointer(Pointer<SimpleBlobDetectorParams> p, [bool attach = true])
factory

Properties

blobColor ↔ int
getter/setter pair
filterByArea ↔ bool
getter/setter pair
filterByCircularity ↔ bool
getter/setter pair
filterByColor ↔ bool
getter/setter pair
filterByConvexity ↔ bool
getter/setter pair
filterByInertia ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isDisposed → bool
Whether this object has been disposed.
no setterinherited
maxArea ↔ double
getter/setter pair
maxCircularity ↔ double
getter/setter pair
maxConvexity ↔ double
getter/setter pair
maxInertiaRatio ↔ double
getter/setter pair
maxThreshold ↔ double
getter/setter pair
minArea ↔ double
getter/setter pair
minCircularity ↔ double
getter/setter pair
minConvexity ↔ double
getter/setter pair
minDistBetweenBlobs ↔ double
getter/setter pair
minInertiaRatio ↔ double
getter/setter pair
minRepeatability ↔ int
getter/setter pair
minThreshold ↔ double
getter/setter pair
props → List<num>
no setteroverride
ptr ↔ Pointer<SimpleBlobDetectorParams>
getter/setter pairinherited
ref → SimpleBlobDetectorParams
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thresholdStep ↔ double
getter/setter pair

Methods

dispose() → void
Releases the underlying native resources. Idempotent: calling it more than once is safe, but the object must not be used after dispose.
inherited
freeNative() → void
Frees the native resources owned by this object. Subclasses implement the concrete free logic here; callers must use dispose instead.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

finalizer → NativeFinalizer
final